module.exports = defineTest({
	description: 'allows unknown binary operators'
});
